==> jc-1.4.0.tar.gz: soot/jimple/JimpleToBafContext.h <==
// public class soot.jimple.JimpleToBafContext

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b9648e27d2a96bdb soot_jimple_JimpleToBafContext

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_JimpleToBafContext_H_
#define _JC_soot_jimple_JimpleToBafContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Local$object;
struct _jc_soot_Unit$object;
struct _jc_soot_baf_BafBody$object;

// Typedefs
typedef struct _jc_soot_jimple_JimpleToBafContext$sub_refs	_jc_soot_jimple_JimpleToBafContext$sub_refs;
typedef struct _jc_soot_jimple_JimpleToBafContext$sub_nonrefs	_jc_soot_jimple_JimpleToBafContext$sub_nonrefs;
typedef struct _jc_soot_jimple_JimpleToBafContext$refs	_jc_soot_jimple_JimpleToBafContext$refs;
typedef struct _jc_soot_jimple_JimpleToBafContext$nonrefs	_jc_soot_jimple_JimpleToBafContext$nonrefs;
typedef struct _jc_soot_jimple_JimpleToBafContext$object	_jc_soot_jimple_JimpleToBafContext$object;

typedef const struct _jc_soot_jimple_JimpleToBafContext$vmethods	_jc_soot_jimple_JimpleToBafContext$vmethods;
typedef const struct _jc_soot_jimple_JimpleToBafContext$vtable	_jc_soot_jimple_JimpleToBafContext$vtable;
typedef const struct _jc_soot_jimple_JimpleToBafContext$vtype	_jc_soot_jimple_JimpleToBafContext$vtype;

// Constructors
extern void _jc_soot_jimple_JimpleToBafContext$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, jint);

// Virtual methods
extern struct _jc_soot_baf_BafBody$object *_jc_soot_jimple_JimpleToBafContext$method$getBafBody$b863abe08f300c75(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *);
extern struct _jc_object *_jc_soot_jimple_JimpleToBafContext$method$getBafLocalOfJimpleLocal$0b0697385f0ea634(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_JimpleToBafContext$method$getCurrentUnit$c0f5efc90b3b0da4(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *);
extern void _jc_soot_jimple_JimpleToBafContext$method$setBafBody$03ecb859a3c07636(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_soot_baf_BafBody$object *);
extern void _jc_soot_jimple_JimpleToBafContext$method$setBafLocalOfJimpleLocal$608c185ea01abc41(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_jimple_JimpleToBafContext$method$setCurrentUnit$2aa7fe5e21eca4d4(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$getBafBody$b863abe08f300c75;
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$getBafLocalOfJimpleLocal$0b0697385f0ea634;
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$getCurrentUnit$c0f5efc90b3b0da4;
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$setBafBody$03ecb859a3c07636;
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$setBafLocalOfJimpleLocal$608c185ea01abc41;
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$setCurrentUnit$2aa7fe5e21eca4d4;

// Virtual methods structure
struct _jc_soot_jimple_JimpleToBafContext$vmethods {
	struct _jc_soot_baf_BafBody$object	*(*getBafBody$b863abe08f300c75)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *);
	struct _jc_object	*(*getBafLocalOfJimpleLocal$0b0697385f0ea634)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
	struct _jc_object	*(*getCurrentUnit$c0f5efc90b3b0da4)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *);
	void	(*setBafBody$03ecb859a3c07636)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_soot_baf_BafBody$object *);
	void	(*setBafLocalOfJimpleLocal$608c185ea01abc41)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *, struct _jc_object *);
	void	(*setCurrentUnit$2aa7fe5e21eca4d4)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_JimpleToBafContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_JimpleToBafContext$vmethods	soot_jimple_JimpleToBafContext;
};

// Vtype
struct _jc_soot_jimple_JimpleToBafContext$vtype {
	_jc_type			type;
	_jc_soot_jimple_JimpleToBafContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_JimpleToBafContext$sub_refs {
	struct _jc_object	*jimpleLocalToBafLocal;
	struct _jc_soot_baf_BafBody$object	*bafBody;
	struct _jc_object	*mCurrentUnit;
};

// Reference instance fields (object)
struct _jc_soot_jimple_JimpleToBafContext$refs {
    _jc_soot_jimple_JimpleToBafContext$sub_refs	soot_jimple_JimpleToBafContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_JimpleToBafContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_JimpleToBafContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_JimpleToBafContext$sub_nonrefs	soot_jimple_JimpleToBafContext;
};

// Object instance structure
struct _jc_soot_jimple_JimpleToBafContext$object {
	_jc_soot_jimple_JimpleToBafContext$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_JimpleToBafContext$vtype	*vtype;
	_jc_soot_jimple_JimpleToBafContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_JimpleToBafContext$vtype _jc_soot_jimple_JimpleToBafContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_JimpleToBafContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_JimpleToBafContext$class_object;

#endif	/* _JC_soot_jimple_JimpleToBafContext_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/JimpleToBafContext.h <==
// public class soot.jimple.JimpleToBafContext

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b9648e27d2a96bdb soot_jimple_JimpleToBafContext

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_JimpleToBafContext_H_
#define _JC_soot_jimple_JimpleToBafContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Local$object;
struct _jc_soot_Unit$object;
struct _jc_soot_baf_BafBody$object;

// Typedefs
typedef struct _jc_soot_jimple_JimpleToBafContext$sub_refs	_jc_soot_jimple_JimpleToBafContext$sub_refs;
typedef struct _jc_soot_jimple_JimpleToBafContext$sub_nonrefs	_jc_soot_jimple_JimpleToBafContext$sub_nonrefs;
typedef struct _jc_soot_jimple_JimpleToBafContext$refs	_jc_soot_jimple_JimpleToBafContext$refs;
typedef struct _jc_soot_jimple_JimpleToBafContext$nonrefs	_jc_soot_jimple_JimpleToBafContext$nonrefs;
typedef struct _jc_soot_jimple_JimpleToBafContext$object	_jc_soot_jimple_JimpleToBafContext$object;

typedef const struct _jc_soot_jimple_JimpleToBafContext$vmethods	_jc_soot_jimple_JimpleToBafContext$vmethods;
typedef const struct _jc_soot_jimple_JimpleToBafContext$vtable	_jc_soot_jimple_JimpleToBafContext$vtable;
typedef const struct _jc_soot_jimple_JimpleToBafContext$vtype	_jc_soot_jimple_JimpleToBafContext$vtype;

// Constructors
extern void _jc_soot_jimple_JimpleToBafContext$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_baf_BafBody$object *_jc_soot_jimple_JimpleToBafContext$method$getBafBody$b863abe08f300c75(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_JimpleToBafContext$method$getBafLocalOfJimpleLocal$0b0697385f0ea634(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_JimpleToBafContext$method$getCurrentUnit$c0f5efc90b3b0da4(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JimpleToBafContext$method$setBafBody$03ecb859a3c07636(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_soot_baf_BafBody$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JimpleToBafContext$method$setBafLocalOfJimpleLocal$608c185ea01abc41(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JimpleToBafContext$method$setCurrentUnit$2aa7fe5e21eca4d4(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$getBafBody$b863abe08f300c75;
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$getBafLocalOfJimpleLocal$0b0697385f0ea634;
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$getCurrentUnit$c0f5efc90b3b0da4;
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$setBafBody$03ecb859a3c07636;
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$setBafLocalOfJimpleLocal$608c185ea01abc41;
extern _jc_method _jc_soot_jimple_JimpleToBafContext$method_info$setCurrentUnit$2aa7fe5e21eca4d4;

// Virtual methods structure
struct _jc_soot_jimple_JimpleToBafContext$vmethods {
	struct _jc_soot_baf_BafBody$object	*(*getBafBody$b863abe08f300c75)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getBafLocalOfJimpleLocal$0b0697385f0ea634)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getCurrentUnit$c0f5efc90b3b0da4)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *) _JC_JCNI_ATTR;
	void	(*setBafBody$03ecb859a3c07636)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_soot_baf_BafBody$object *) _JC_JCNI_ATTR;
	void	(*setBafLocalOfJimpleLocal$608c185ea01abc41)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setCurrentUnit$2aa7fe5e21eca4d4)(_jc_env *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_JimpleToBafContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_JimpleToBafContext$vmethods	soot_jimple_JimpleToBafContext;
};

// Vtype
struct _jc_soot_jimple_JimpleToBafContext$vtype {
	_jc_type			type;
	_jc_soot_jimple_JimpleToBafContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_JimpleToBafContext$sub_refs {
	struct _jc_object	*jimpleLocalToBafLocal;
	struct _jc_soot_baf_BafBody$object	*bafBody;
	struct _jc_object	*mCurrentUnit;
};

// Reference instance fields (object)
struct _jc_soot_jimple_JimpleToBafContext$refs {
    _jc_soot_jimple_JimpleToBafContext$sub_refs	soot_jimple_JimpleToBafContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_JimpleToBafContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_JimpleToBafContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_JimpleToBafContext$sub_nonrefs	soot_jimple_JimpleToBafContext;
};

// Object instance structure
struct _jc_soot_jimple_JimpleToBafContext$object {
	_jc_soot_jimple_JimpleToBafContext$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_JimpleToBafContext$vtype	*vtype;
	_jc_soot_jimple_JimpleToBafContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_JimpleToBafContext$vtype _jc_soot_jimple_JimpleToBafContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_JimpleToBafContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_JimpleToBafContext$class_object;

#endif	/* _JC_soot_jimple_JimpleToBafContext_H_ */
